@@ -457,14 +457,6 @@ def get_cli_parser() -> argparse.ArgumentParser:
         default=None,
         help=f"Specify ignore file to use. By default it will look for '{IGNORE_FILE.default}' or '{IGNORE_FILE.alternative}'",
     )
-    parser.add_argument(
-        "-I",
-        "--inventory",
-        dest="inventory",
-        action="append",
-        type=str,
-        help="Specify inventory host path or comma separated host list",
-    )
     parser.add_argument(
         "--offline",
         dest="offline",
@@ -527,7 +519,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Options) -> Options:
                 setattr(cli_config, entry, default)
         if cli_config.write_list is None:
             cli_config.write_list = []
-        elif cli_config.write_list == [WriteArgAction._default]:  # noqa: SLF001
+        elif cli_config.write_list == [WriteArgAction._default]:  # noqa: SLF001 # pragma: no cover
             cli_config.write_list = ["all"]
         return cli_config
 
